@@ -21,12 +21,12 @@ set -x
 aclocal --install || exit 1
 intltoolize --force --copy --automake || exit 1
 autoreconf --verbose --force --install -Wno-portability || exit 1
-set +x
+{ set +x; } 2>/dev/null
 
 if [ "$NOCONFIGURE" = "" ]; then
         set -x
         $srcdir/configure "$@" || exit 1
-        set +x
+        { set +x; } 2>/dev/null
 
         if [ "$1" = "--help" ]; then exit 0 else
                 echo "Now type \`make\' to compile $PKG_NAME" || exit 1
